@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: arch.h,v 1.31 2000/05/16 18:52:14 ezust Exp $
+ $Id: arch.h,v 1.35 2000/07/10 20:03:46 ezust Exp $
 
  ark -- archiver for the KDE project
 
@@ -43,6 +43,12 @@
 class KProcess;
 class Viewer;
 
+
+enum ArchType {UNKNOWN_FORMAT, ZIP_FORMAT, TAR_FORMAT, AA_FORMAT,
+	       LHA_FORMAT, RAR_FORMAT, ZOO_FORMAT, COMPRESSED_FORMAT};
+
+ArchType getArchType( const QString & archname, QString &extension);
+
 // The following class is the base class for all of the archive types.
 // In order for it to work properly with the KProcess, you have to
 // connect the ProcessExited signal appropriately before spawning
@@ -51,13 +57,20 @@ class Viewer;
 // appropriately. See LhaArch or ZipArch for a good model. Don't use
 // TarArch or CompressedFile as models - they're too complicated!
 //
+// Don't forget to set m_archiver_program and m_unarchiver_program
+// and add a call to 
+//     verifyUtilityIsAvailable(m_archiver_program, m_unarchiver_program);
+// in the constructor of your class. It's OK to leave out the second argument.
 //
 // To add a new archive:
 // 1. Create a new header file and a source code module
-// 2. Add an entry to the ArchType enum in arkwidget.h.
+// 2. Add an entry to the ArchType enum in arch.h.
 // 3. Include your new header file in arkwidget.cc.
-// 4. Add new cases for your format in createArchive(const QString &),
-//   openArchive(const QString &) and ArkWidget::getArchType().
+// 4. Add new cases for your format in 
+//    ArkWidget::createArchive(const QString &),
+//    ArkWidget::openArchive(const QString &)
+// and
+//    getArchType() in arch.cpp
 // 5. Add your extension to the list of valid archives in 
 //   ArkSettings::getFilter (you might also want to add a separate entry)
 //
@@ -81,7 +94,7 @@ public:
   virtual void unarchFile(QStringList *, const QString & _destDir="") = 0;
 
   QString fileName() const { return m_filename; };
-	
+
   enum EditProperties{ Add = 1, Delete = 2, Extract = 4,
     View = 8, Integrity = 16 };
 
@@ -92,6 +105,14 @@ public:
 
   void setReadOnly(bool bVal) { m_bReadOnly = bVal; }
 
+  // check to see if the utility exists in the PATH of the user
+  void verifyUtilityIsAvailable(const QString &,
+				const QString & = QString::null);
+
+  bool utilityIsAvailable() { return m_bUtilityIsAvailable; }
+
+  QString getUtility() { return m_archiver_program; }
+
 protected slots:
   void slotCancel();
   void slotStoreDataStdout(KProcess*, char*, int);
@@ -122,6 +143,11 @@ protected:  // data
   // lets tar delete unsuccessfully before adding without confusing the user
   bool m_bNotifyWhenDeleteFails; 
 
+  // set to whether the archiving utility/utilities is/are in the user's PATH
+  bool m_bUtilityIsAvailable;
+
+  QString m_archiver_program;
+  QString m_unarchiver_program;
 };
 
 // various functions for massaging timestamps
@@ -137,7 +163,7 @@ namespace Utils
 }
 
 // Column header strings
-
+// don't forget to change common_texts.cpp if you change something here
 #define FILENAME_STRING i18n(" Filename ")
 #define PERMISSION_STRING i18n(" Permissions ")
 #define OWNER_GROUP_STRING i18n(" Owner/Group ")
@@ -146,7 +172,7 @@ namespace Utils
 #define LINK_STRING i18n(" Link ")
 #define PACKED_STRING i18n(" Size Now ")
 #define RATIO_STRING i18n(" Ratio ")
-#define CRC_STRING i18n(" CRC ")
+#define CRC_STRING i18n("acronym for Cyclic Redundancy Check"," CRC ")
 #define METHOD_STRING i18n(" Method ")
 #define VERSION_STRING i18n(" Version ")
 #define OWNER_STRING i18n(" Owner ")
