@@ -1,6 +1,6 @@
 /*
 
- $Id: arkapp.cpp,v 1.13 2000/06/01 19:31:21 ezust Exp $
+ $Id: arkapp.cpp,v 1.19 2000/10/08 20:24:14 faure Exp $
 
  ark -- archiver for the KDE project
 
@@ -52,7 +52,7 @@ static QString resolveFilename(const QString & _arkname)
   while (1)
     {
       buff = new char[BUFSIZ*iter];
-      nread = readlink( (const char *)_arkname,
+      nread = readlink( QFile::encodeName(_arkname),
 			buff, BUFSIZ);
       if (-1 == nread)
 	{
@@ -65,7 +65,7 @@ static QString resolveFilename(const QString & _arkname)
 	      delete buff;
 	      continue;
 	    }
-	  else 
+	  else
 	    {
 	      // the other errors will be taken care of already in simply
 	      // opening the archive (i.e., the user will be notified)
@@ -75,11 +75,11 @@ static QString resolveFilename(const QString & _arkname)
       else
 	{
 	  buff[nread] = '\0';  // readlink doesn't null terminate
-	  QString name(buff);
+	  QString name = QFile::decodeName(buff);
 	  delete buff;
 
 	  // watch out for relative pathnames
-	  if (name.left(1) != '/')
+	  if (name.at(0) != '/')
 	    {
 	      // copy the path from _arkname
 	      int index = _arkname.findRev('/');
@@ -101,7 +101,7 @@ ArkApplication * ArkApplication::getInstance()
 }
 
 ArkApplication::ArkApplication()
-  : KUniqueApplication(), m_windowCount(0)
+  : KUniqueApplication(), m_windowCount(0), m_isSessionRestored(isRestored())
 {
   kdDebug(1601) << "+ArkApplication::ArkApplication" << endl;
   m_mainwidget = new QWidget;
@@ -113,33 +113,38 @@ int ArkApplication::newInstance()
 {
   kdDebug(1601) << "+ArkApplication::newInstance" << endl;
 
+  // If we are restored by session management, we don't need to open
+  // another window on startup.
+  if ( m_isSessionRestored )
+  {
+    // But next invocations must still come through.
+    // NOTE: IMHO this should be handled by KUniqueApplication itself
+    m_isSessionRestored = false;
+    kdDebug(1601) << "-ArkApplication::newInstance no new window since restored by SM" << endl;
+    return 0;
+  }
+
   QString Zip;
+
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+  KURL url;
 
-  if (args->count() > 0) 
-  {
-     const char *arg = args->arg(0);
-     if (arg[0] == '/')
-     {
-        Zip = QFile::decodeName(arg);
-     }
-     else if (QString(arg).left(7) != "http://" &&
-	      QString(arg).left(6) != "ftp://")
-     {
-        Zip = KCmdLineArgs::cwd() + "/" + QFile::decodeName(arg);
-     }
-  }
+  int i = 0;
+  do {
+    if (args->count() > 0)
+      url = args->url(i);
+    ArkWidget *arkWin = new ArkWidget(m_mainwidget);
+    arkWin->show();
+    arkWin->resize(640, 300);
+
+    if (!url.isEmpty())
+      {
+	arkWin->file_open(url);
+      }
+    kdDebug(1601) << "-ArkApplication::newInstance" << endl;
+    ++i;
+  } while  (i < args->count());
   args->clear();
-
-  ArkWidget *arkWin = new ArkWidget(m_mainwidget);
-  arkWin->show();
-  arkWin->resize(640, 300);
-
-  if (!Zip.isEmpty())
-  {
-    arkWin->file_open(Zip);
-  }
-  kdDebug(1601) << "-ArkApplication::newInstance" << endl;
   return 0;
 }
 
@@ -149,9 +154,9 @@ void ArkApplication::addOpenArk(const QString & _arkname,
 {
   kdDebug(1601) << "+ArkApplication::addOpenArk" << endl;
   QString realName = resolveFilename(_arkname);  // follow symlink
-  kdDebug(1601) << "---------------- Real name of " << (const char *)_arkname << " is " << (const char *)realName << endl;
+  kdDebug(1601) << "---------------- Real name of " << _arkname << " is " << realName << endl;
   openArksList.append(realName);
-  m_windowsHash[realName] = _ptr;
+  m_windowsHash.replace(realName, _ptr);
   kdDebug(1601) << "---------------Saved ptr " << _ptr << endl;
   kdDebug(1601) << "-ArkApplication::addOpenArk" << endl;
 }
@@ -160,14 +165,14 @@ void ArkApplication::removeOpenArk(const QString & _arkname)
 {
   kdDebug(1601) << "+ArkApplication::removeOpenArk" << endl;
   QString realName = resolveFilename(_arkname);  // follow symlink
-  kdDebug(1601) << "Removing name " << (const char *)_arkname << endl;
+  kdDebug(1601) << "Removing name " << _arkname << endl;
   openArksList.remove(realName);
-  m_windowsHash.erase(realName);
+  m_windowsHash.remove(realName);
   kdDebug(1601) << "-ArkApplication::removeOpenArk" << endl;
 }
 
 void ArkApplication::raiseArk(const QString & _arkname)
-{ 
+{
   ArkWidget *window;
   QString realName = resolveFilename(_arkname);  // follow symlink
   window = m_windowsHash[realName];
@@ -183,7 +188,7 @@ void ArkApplication::raiseArk(const QString & _arkname)
 bool ArkApplication::isArkOpenAlready(const QString & _arkname)
 {
   QString realName = resolveFilename(_arkname);  // follow symlink
-  return (openArksList.findIndex(realName) != -1); 
+  return (openArksList.findIndex(realName) != -1);
 }
 
 
