@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: extractdlg.h,v 1.15 2000/05/23 21:50:26 ezust Exp $
+ $Id: extractdlg.h,v 1.16 2000/06/28 21:30:16 ezust Exp $
 
  ark -- archiver for the KDE project
  
@@ -35,7 +35,7 @@
 #include <qcheckbox.h>
 #include "arkwidget.h"  // for ArchType
 
-class QLineEdit;
+class QComboBox;
 class ArkSettings;
 
 class ExtractDlg : public QTabDialog 
@@ -63,7 +63,7 @@ private: // methods
 private: // data
   QRadioButton *m_radioCurrent, *m_radioAll, *m_radioSelected, *m_radioPattern;
   QLineEdit *m_patternLE;
-  QLineEdit *m_extractDirLE;
+  QComboBox *m_extractDirCB;
   ArkSettings *m_settings;
   ArchType m_archtype;
   // advanced options 
