@@ -1,6 +1,6 @@
 /*
 
-  $Id: filelistview.cpp,v 1.17 2000/06/02 19:37:34 ezust Exp $
+  $Id: filelistview.cpp,v 1.18 2000/08/01 16:06:38 bieker Exp $
 
   ark -- archiver for the KDE project
 
@@ -70,15 +70,12 @@ QString FileLVI::key(int column, bool ascending) const
     if ( columnName == SIZE_STRING ||
 	 columnName == PACKED_STRING )
       {
-	s.sprintf("%.10ld", atol(text(column)));
+	s.sprintf("%.10ld", text(column).toInt());
 	return s;
       }
     else if (columnName == RATIO_STRING)
       {
-	char ratio[5];
-	strcpy(ratio, text(column));
-	ratio[strlen(ratio) - 1] = '\0';
-	s.sprintf("%.10ld", atol(ratio));
+	s.sprintf("%.10ld", text(column).toInt());
 	return s;
       }
     else return QListViewItem::key(column, ascending);
