@@ -1,6 +1,6 @@
 /*
 
- $Id: tar.cc,v 1.36 2000/05/12 20:52:00 ezust Exp $
+ $Id: tar.cc,v 1.40 2000/08/01 16:06:38 bieker Exp $
 
  ark -- archiver for the KDE project
 
@@ -56,6 +56,8 @@
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <ktempfile.h>
+#include <kmimemagic.h>
 
 // ark includes
 #include "viewer.h"
@@ -73,8 +75,13 @@ TarArch::TarArch( ArkSettings *_settings, Viewer *_gui,
 {
   kdDebug(1601) << "+TarArch::TarArch" << endl;
   m_archiver_program = m_settings->getTarCommand();
+  m_unarchiver_program = QString::null;
+  verifyUtilityIsAvailable(m_archiver_program, m_unarchiver_program);
 
-  if (_filename.right(4) == ".tar")
+  KMimeMagic *mimePtr = KMimeMagic::self();
+  KMimeMagicResult * mimeResultPtr = mimePtr->findFileType(_filename);
+  QString mimetype = mimeResultPtr->mimeType();
+  if (mimetype == "application/x-tar")
     {
       compressed = false;
     }
@@ -89,16 +96,20 @@ TarArch::TarArch( ArkSettings *_settings, Viewer *_gui,
       base = base.left(base.findRev("."));
       
       // build the temp file name
-      tmpfile.sprintf("%s/temp_tar_%s.%d", (const char *)tmpdir,
-		      (const char *)base, getpid());
-      kdDebug(1601) << "Tmpfile will be " << (const char *)tmpfile.local8Bit() << "\n" << endl;
+      
+      KTempFile *pTempFile = new KTempFile(tmpdir +
+					   QString::fromLatin1("/temp_tar"),
+					   QString::fromLatin1(".tar"));
+
+      tmpfile = pTempFile->name();
+      kdDebug(1601) << "Tmpfile will be " << tmpfile << "\n" << endl;
     }
   kdDebug(1601) << "-TarArch::TarArch" << endl;
 }
 
 TarArch::~TarArch()
 {
-  unlink((const char *)tmpfile);
+  unlink( QFile::encodeName(tmpfile) );
 }
 
 int TarArch::getEditFlag()
@@ -112,11 +123,11 @@ void TarArch::updateArch()
   if (compressed)
     {
       updateInProgress = true;
-      fd = fopen( m_filename.local8Bit(), "w" );
+      fd = fopen( QFile::encodeName(m_filename), "w" );
 
       KProcess *kp = new KProcess;
       kp->clearArguments();
-      *kp << getCompressor() << "-c" << tmpfile.local8Bit();
+      *kp << getCompressor() << "-c" << tmpfile;
 
       connect(kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	      this, SLOT(updateProgress( KProcess *, char *, int )));
@@ -153,7 +164,7 @@ QString TarArch::getCompressor()
 {
   QString extension = m_filename.right(m_filename.length() -
 				       m_filename.findRev('.') );
-  kdDebug(1601) << "Extension: " << (const char *)extension << endl;
+  kdDebug(1601) << "Extension: " << extension << endl;
 
   if( extension == ".tgz" || extension == ".gz" ) 
     return QString( "gzip" );
@@ -172,7 +183,7 @@ QString TarArch::getUnCompressor()
 {
   QString extension = m_filename.right(m_filename.length() -
 				       m_filename.findRev('.'));
-  kdDebug(1601) << "Extension: " << (const char *)extension << endl;
+  kdDebug(1601) << "Extension: " << extension << endl;
   if( extension == ".tgz" || extension == ".gz" ) 
     return QString( "gunzip" );
   if( extension == ".bz")
@@ -189,7 +200,7 @@ QString TarArch::getUnCompressor()
 void TarArch::open()
 {
   kdDebug(1601) << "+TarArch::open" << endl;
-  unlink((const char *)tmpfile); // just to make sure
+  unlink( QFile::encodeName(tmpfile) ); // just to make sure
   setHeaders();
   KTarGz *tarptr;
 
@@ -223,10 +234,10 @@ void TarArch::open()
   // might as well plunk the output of tar -tvf in the shell output window...
   KProcess *kp = new KProcess;
 
-  *kp << m_archiver_program.local8Bit() ;
+  *kp << m_archiver_program;
   if (compressed)
     *kp << "--use-compress-program="+getUnCompressor() ;
-  *kp << "-tvf" << m_filename.local8Bit();
+  *kp << "-tvf" << m_filename;
   connect(kp, SIGNAL(processExited(KProcess *)),
 	  this, SLOT(slotListingDone(KProcess *)));
   connect(kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
@@ -263,8 +274,8 @@ void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
       if (root.isEmpty() || root.isNull())
 	name = tarEntry->name();
       else
-	name = root + "/" + tarEntry->name();
-      col_list.append(QString::fromLocal8Bit(name));
+	name = root + '/' + tarEntry->name();
+      col_list.append( name );
       QString perms = makeAccessString(tarEntry->permissions());
       if (!tarEntry->isFile())
 	perms = "d" + perms;
@@ -272,20 +283,20 @@ void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
 	perms = "l" + perms;
       else
 	perms = "-" + perms;
-      col_list.append(QString::fromLocal8Bit(perms));
+      col_list.append(perms);
       QString usergroup = tarEntry->user();
       usergroup += '/';
       usergroup += tarEntry->group();
-      col_list.append(QString::fromLocal8Bit(usergroup));
+      col_list.append( usergroup );
       QString strSize = "0";
       if (tarEntry->isFile())
 	{
 	  strSize.sprintf("%d", ((KTarFile *)tarEntry)->size());
 	}
-      col_list.append(QString::fromLocal8Bit(strSize));
+      col_list.append(strSize);
       QString timestamp = makeTimeStamp(tarEntry->datetime());
-      col_list.append(QString::fromLocal8Bit(timestamp));
-      col_list.append(QString::fromLocal8Bit(tarEntry->symlink()));
+      col_list.append(timestamp);
+      col_list.append(tarEntry->symlink());
       m_gui->add(&col_list); // send the entry to the GUI
 
       // if it isn't a file, it's a directory - process it.
@@ -335,7 +346,7 @@ void TarArch::createTmp()
   if (compressed)
     {
       struct stat statbuffer;
-      if (stat((const char *)tmpfile, &statbuffer) == -1)
+      if (stat(QFile::encodeName(tmpfile), &statbuffer) == -1)
 	{
 	  // the tmpfile does not yet exist, so we create it.
 	  createTmpInProgress = true;
@@ -344,7 +355,7 @@ void TarArch::createTmp()
 	  KProcess *kp = new KProcess;
 	  kp->clearArguments();
 	  QString strUncompressor = getUnCompressor();
-	  kdDebug(1601) << "Uncompressor is " << (const char *)strUncompressor << endl;
+	  kdDebug(1601) << "Uncompressor is " << strUncompressor << endl;
 	  *kp << strUncompressor;
 	  if (strUncompressor == "lzop")
 	    {
@@ -391,7 +402,8 @@ static QDateTime getMTime(const QString & entry)
 {
   // I have something like: 1999-10-04 11:04:44
   int year, month, day, hour, min, seconds;
-  sscanf( (const char *)entry, "%d-%d-%d %d:%d:%d", &year, &month, &day, &hour,
+  // HPB: should be okay 'cause the date format will not be localized
+  sscanf( entry.ascii(), "%d-%d-%d %d:%d:%d", &year, &month, &day, &hour,
 	  &min, &seconds);
 
   QDate theDate(year, month, day);
@@ -430,7 +442,7 @@ void TarArch::deleteOldFiles(QStringList *urls, bool bAddOnlyNew)
       QString entryTimeStamp = m_gui->getColData(str, col);
       if (entryTimeStamp.isNull())
 	continue;  // it isn't in there, so skip it.
-      stat(filename, &statbuffer);
+      stat(QFile::encodeName(filename), &statbuffer);
       time_t the_mtime = statbuffer.st_mtime;
       struct tm *convertStruct = localtime(&the_mtime);
       QDateTime addFileMTime(QDate(convertStruct->tm_year,
@@ -460,9 +472,7 @@ void TarArch::deleteOldFiles(QStringList *urls, bool bAddOnlyNew)
     }
     list.append(str);
 
-#ifdef DEBUG
-    fprintf(stderr, "To delete: %s\n", (const char *)str);
-#endif
+    kdDebug() << "To delete: " << str << endl;
   }
   remove(&list);
 }
@@ -516,7 +526,7 @@ void TarArch::addFile( QStringList* urls )
       int pos;
       pos = file.findRev( '/', -1, FALSE );
       base = file.left( ++pos );
-      kdDebug(1601) << "base is " << (const char *)base << endl;
+      kdDebug(1601) << "base is " << base << endl;
       //		pos++;
       tmp = file.right( file.length()-pos );
       file = tmp;
@@ -545,7 +555,7 @@ void TarArch::addFile( QStringList* urls )
   QStrList list(*ptr); // copied because of const probs
   for ( strTemp=list.first(); strTemp != 0; strTemp=list.next() )
     {
-      kdDebug(1601) << (const char *)strTemp << " " << endl;
+      kdDebug(1601) << strTemp << " " << endl;
     }
 
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
@@ -666,7 +676,7 @@ void TarArch::remove(QStringList *list)
 
   for ( QStringList::Iterator it = list->begin(); it != list->end(); ++it )  
     {
-      kdDebug(1601) << (const char *)*it << endl;
+      kdDebug(1601) << *it << endl;
       *kp << *it;
     }
 
@@ -799,6 +809,6 @@ static QString makeTimeStamp(const QDateTime & dt)
 
   timestamp.sprintf("%d-%02d-%02d %s",
 		    d.year(), d.month(), d.day(),
-		    (const char *)t.toString());
+		    t.toString().utf8().data());
   return timestamp;
 }
