@@ -1,29 +1,19 @@
 /* -*- C++ -*-
- * This file implements the dialog that is used to set file specific
- * information.
- * 
- * the KDE addressbook
- * copyright:  (C) Mirko Sucker, 1998 1999, 2000
- * mail to:    Mirko Sucker <mirko@kde.org>
- * requires:   recent C++-compiler, at least Qt 2.0
- 
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Library General Public
- License as published by the Free Software Foundation; either
- version 2 of the License, or (at your option) any later version.
- 
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Library General Public License for more details.
- 
- You should have received a copy of the GNU Library General Public License
- along with this library; see the file COPYING.LIB.  If not, write to
- the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- Boston, MA 02111-1307, USA.
- 
- * $Revision: 1.6 $
- */
+   This file implements the dialog that is used to set file specific
+   information.
+   
+   the KDE addressbook
+
+   $ Author: Mirko Boehm $
+   $ Copyright: (C) 1996-2000, Mirko Boehm $
+   $ Contact: mirko@kde.org
+         http://www.kde.org $
+   $ License: GPL with the following explicit clarification:
+         This code may be linked against any version of the Qt toolkit
+         from Troll Tech, Norway. $
+
+   $Revision: 1.10 $
+*/
 
 #include "dialog_configurefile.h"
 #include <qtabwidget.h>
@@ -130,6 +120,22 @@ KabFileConfigWidget::KabFileConfigWidget(Section* config, QWidget* parent,
 	      kdDebug() << "TabUser::configure: missing settings " <<
 			 "in configuration section!";
 	    }
+
+          if( (0 == count) && ("(User fields)" == text) )
+            text = i18n("(User fields)");
+ 
+          else if( (1 == count) && ("(User field 1)" == text) )
+            text = i18n("(User field 1)");
+ 
+          else if( (2 == count) && ("(User field 2)" == text) )
+            text = i18n("(User field 2)");
+ 
+          else if( (3 == count) && ("(User field 3)" == text) )
+            text = i18n("(User field 3)");
+ 
+          else if( (4 == count) && ("(User field 4)" == text) )
+            text = i18n("(User field 4)");                                      
+
 	  *ledits[count]=new QLineEdit(text, userFields);
 	  if(*labels[count]==0 || *ledits[count]==0)
 	    {
@@ -193,3 +199,4 @@ KabFileConfigWidget::saveSettings(Section *config)
   // ###########################################################################
 }
 
+#include "dialog_configurefile.moc"
