@@ -1,28 +1,18 @@
 /* -*- C++ -*-
- * This file implements the method to create new addressbook files..
- * 
- * the KDE addressbook
- * copyright:  (C) Mirko Sucker, 1998 1999, 2000
- * mail to:    Mirko Sucker <mirko@kde.org>
- * requires:   recent C++-compiler, at least Qt 2.0
- 
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Library General Public
- License as published by the Free Software Foundation; either
- version 2 of the License, or (at your option) any later version.
- 
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Library General Public License for more details.
- 
- You should have received a copy of the GNU Library General Public License
- along with this library; see the file COPYING.LIB.  If not, write to
- the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- Boston, MA 02111-1307, USA.
- 
- * $Revision: 1.10 $
- */
+   This file implements the method to create new addressbook files..
+
+   the KDE addressbook
+
+   $ Author: Mirko Boehm $
+   $ Copyright: (C) 1996-2000, Mirko Boehm $
+   $ Contact: mirko@kde.org
+         http://www.kde.org $
+   $ License: GPL with the following explicit clarification:
+         This code may be linked against any version of the Qt toolkit
+         from Troll Tech, Norway. $
+
+   $Revision: 1.14 $	
+*/
 
 #include <kabapi.h>
 #include <kfiledialog.h>
@@ -58,7 +48,7 @@ void TopLevelWidget::createNew()
     {
       // dummy=KFileDialog::getOpenFileName(home, "*kab", this);
       dummy=KFileDialog::getOpenURL(home, "*kab", this);
-      kdDebug() << "KabMainWindow::newFile: URL is " << dummy.url().data();
+      kdDebug() << "KabMainWindow::newFile: URL is " << dummy.url() << endl;
       if(dummy.isEmpty()) // dialog has been cancelled
 	{
 	  setStatus(i18n("Cancelled."));
@@ -87,7 +77,7 @@ void TopLevelWidget::createNew()
 		  "to create the new file."),
 	     i18n("File error"));
 	} else {
-	  kdDebug() << "KabMainWindow::newFile: filename is " << filename.data();
+	  kdDebug() << "KabMainWindow::newFile: filename is " << filename << endl;
 	  break;
 	}
     }
@@ -98,7 +88,7 @@ void TopLevelWidget::createNew()
       KMessageBox::information
 	(this,
 	 i18n("The filename did not end with \".kab\".\n"
-	      "It has been changed to\n")+filename,
+	      "It has been changed to %1\n").arg(filename),
 	 i18n("Note"));
     }
   // ----- create the new database file:
