@@ -1,29 +1,21 @@
-/* This file implements the business card look.
- *
- * the KDE addressbook
- * copyright:  (C) Mirko Sucker, 1998, 1999, 2000
- * mail to:    Mirko Sucker <mirko@kde.org>
- * requires:   recent C++-compiler, at least Qt 2.0
- 
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Library General Public
- License as published by the Free Software Foundation; either
- version 2 of the License, or (at your option) any later version.
- 
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Library General Public License for more details.
- 
- You should have received a copy of the GNU Library General Public License
- along with this library; see the file COPYING.LIB.  If not, write to
- the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- Boston, MA 02111-1307, USA.
- 
- * $Revision: 1.9 $
- */
+/* -*- C++ -*-
+   This file implements the business card look.
+
+   the KDE addressbook
+	 
+   $ Author: Mirko Boehm $
+   $ Copyright: (C) 1996-2000, Mirko Boehm $
+   $ Contact: mirko@kde.org
+         http://www.kde.org $
+   $ License: GPL with the following explicit clarification:
+         This code may be linked against any version of the Qt toolkit
+         from Troll Tech, Norway. $
+
+   $Revision: 1.16 $
+*/
 
 #include "look_businesscard.h"
+#include "look_edit.h"
 #include <qstringlist.h>
 #include <qpixmap.h>
 #include <qpainter.h>
@@ -31,6 +23,7 @@
 #include <qtooltip.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kglobal.h>
 
 
 #define GRID 5
@@ -66,7 +59,13 @@ KABBusinessCard::KABBusinessCard(KabAPI* api, QWidget* parent, const char* name)
 	  SLOT(homeURLClicked(const QString&)));
   connect(addressCombo, SIGNAL(activated(int)),
 	  SLOT(addressSelected(int)));
-  resize(310, 160);
+  // ----- find preferred size:
+  // Since the business card look does not prefer a size it uses the
+  // preferred size of the editing look to avoid flickering resizing.
+  KABEditLook *editlook=new KABEditLook(api, this);
+  setMinimumSize(editlook->minimumSizeHint());
+  // resize(minimumSize()); // is this needed?
+  delete editlook;
 }
 
 KABBusinessCard::~KABBusinessCard()
@@ -113,7 +112,7 @@ void KABBusinessCard::paintEvent(QPaintEvent*)
     { // if there is none, address simply remains empty
       if(current.getAddress(currentAddress, address)!=AddressBook::NoError)
 	{
-	  kdDebug() << "AddressBook::paintEvent: address index out of range!";
+	  kdDebug() << "AddressBook::paintEvent: address index out of range!" << endl;
 	}
     }
   // ----- draw the background:
@@ -221,9 +220,8 @@ void KABBusinessCard::paintEvent(QPaintEvent*)
       // ----- print the birthday in the upper right corner if it is valid:
       if(current.birthday.isValid())
 	{ //       by now I do not take care if there is enough space left
-	  p.drawText
-	    (pm.width()-Grid-p.fontMetrics().width(current.birthday.toString()),
-	     Grid+p.fontMetrics().ascent(), current.birthday.toString());
+          p.drawText(pm.width()-Grid-p.fontMetrics().width(KGlobal::locale()->formatDate(current.birthday)),
+	     Grid+p.fontMetrics().ascent(), KGlobal::locale()->formatDate(current.birthday));
 	}
       // ----- draw the address, begin on top
       cy=Grid;
@@ -388,3 +386,4 @@ void KABBusinessCard::addressSelected(int index)
 
   
 
+#include "look_businesscard.moc"
