@@ -1,27 +1,18 @@
-/* This file implements the tab to edit the addresses.
- *
- * the KDE addressbook
- * copyright:  (C) Mirko Sucker, 1998, 1999, 2000
- * mail to:    Mirko Sucker <mirko@kde.org>
- * requires:   recent C++-compiler, at least Qt 2.0
+/* -*- C++ -*-
+   This file implements the tab to edit the addresses.
  
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Library General Public
- License as published by the Free Software Foundation; either
- version 2 of the License, or (at your option) any later version.
- 
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Library General Public License for more details.
- 
- You should have received a copy of the GNU Library General Public License
- along with this library; see the file COPYING.LIB.  If not, write to
- the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- Boston, MA 02111-1307, USA.
- 
- * $Revision: 1.10 $
- */
+   the KDE addressbook
+   
+   $ Author: Mirko Boehm $
+   $ Copyright: (C) 1996-2000, Mirko Boehm $
+   $ Contact: mirko@kde.org
+         http://www.kde.org $
+   $ License: GPL with the following explicit clarification:
+         This code may be linked against any version of the Qt toolkit
+         from Troll Tech, Norway. $
+
+   $Revision: 1.17 $	 
+*/
 
 #include "look_edit_tabaddresses.h"
 #include <qcombobox.h>
@@ -37,9 +28,12 @@
 #include <qtooltip.h>
 #include <kmessagebox.h>
 #include <kiconloader.h>
+#include <kdialogbase.h>
 #include <klocale.h>
 #include <qconfigDB.h>
+#include <kdebug.h>
 #include <kapp.h>
+#include "dialog_insinuation.h"
 
 #define KEY_ADDRESSTYPES "AddressTypes"
 
@@ -154,13 +148,13 @@ TabAddresses::TabAddresses(KabAPI* api, QWidget *parent)
   ++row;
   // ----- finish the layout:
   layout->setRowStretch(row, 1);
-  debug("TabAddresses::TabAddresses: needed %i rows.", ++row);
   // ----- create the "choices of address types" menu:
   popupAddresses=new QPopupMenu;
   section=api->addressbook()->configurationSection();
   if(section==0)
     {
-      debug("TabAddresses ctor: configuration section not available.");
+      kdDebug() << "TabAddresses ctor: configuration section not available."
+		<< endl;
     } else {
       keys=section->getKeys();
       if(keys->get(KEY_ADDRESSTYPES, types))
@@ -170,7 +164,8 @@ TabAddresses::TabAddresses(KabAPI* api, QWidget *parent)
 	      popupAddresses->insertItem(*types.at(count), count);
 	    }
 	} else {
-	  debug("TabAddresses ctor: address types not configured.");
+	  kdDebug() << "TabAddresses ctor: address types not configured."
+		    << endl;
 	}
     }
 }
@@ -318,7 +313,6 @@ void TabAddresses::fillSelector()
 
 std::list<AddressBook::Entry::Address>::iterator TabAddresses::currentAddress()
 {
-  debug("TabAddresses::currentAddress: seeking address %i.", currentItem);
   std::list<AddressBook::Entry::Address>::iterator pos;
   int index=currentItem;
   // ----- find the current address:
@@ -333,8 +327,6 @@ std::list<AddressBook::Entry::Address>::iterator TabAddresses::currentAddress()
 	  index=currentItem;
 	  pos=addresses.begin();
 	  advance(pos, index);
-	  debug("TabAddresses::currentAddress: found %s.",
-		(const char*)(*pos).headline.utf8());
 	  return pos;
 	}
     }
@@ -463,8 +455,7 @@ void TabAddresses::deleteAddress()
 
 void TabAddresses::highlighted(int index)
 {
-  debug("TabAddresses::highlighted: %i (was %i).", index,
-	currentItem);
+  kdDebug() << "TabAddresses::highlighted: " << index << " (was " << currentItem << ")." << endl;
   if(modified)
     {
       storeChanges();
@@ -481,7 +472,6 @@ void TabAddresses::addressChanged()
 {
   modified=true;
   emit(changed());
-  debug("TabAddresses::addressChanged: address changed.");
 }
 
 void TabAddresses::headlineChanged(const QString &text)
@@ -499,5 +489,23 @@ void TabAddresses::addressChanged(const QString &)
 
 void TabAddresses::insinuation()
 {
-  debug("TabAddresses::insinuation: NI.");
+  std::list<AddressBook::Entry::Address>::iterator pos;  
+  KDialogBase dialog
+    (this, "InsinuationDialog", true, i18n("Insinuation"),
+     KDialogBase::Ok|KDialogBase::Cancel,
+     KDialogBase::Ok, true);
+  InsinuationDialog in(&dialog);
+  pos=addresses.begin();
+  advance(pos, currentItem);
+  in.setFields(*pos);
+  dialog.setMainWidget(&in);
+  if(dialog.exec())
+    {
+      in.getFields(*pos);
+      emit(changed());
+    } else {
+    }
 }
+
+	       
+#include "look_edit_tabaddresses.moc"
