@@ -1,28 +1,19 @@
 /* -*- C++ -*-
- * This file implements a widget for navigating through sets of data.
- * 
- * the K Desktop Environment
- * copyright:  (C) Mirko Sucker, 1999
- * mail to:    Mirko Sucker <mirko.sucker@unibw-hamburg.de>
- * requires:   recent C++-compiler, at least Qt 1.4, STL
- 
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Library General Public
- License as published by the Free Software Foundation; either
- version 2 of the License, or (at your option) any later version.
- 
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Library General Public License for more details.
- 
- You should have received a copy of the GNU Library General Public License
- along with this library; see the file COPYING.LIB.  If not, write to
- the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- Boston, MA 02111-1307, USA.
- 
- * $Revision: 1.7 $
- */
+   This file implements a widget for navigating through sets of data.
+  
+   the K Desktop Environment
+
+   $ Author: Mirko Boehm $
+   $ Copyright: (C) 1996-2000, Mirko Boehm $
+   $ Contact: mirko@kde.org
+         http://www.kde.org $
+   $ License: GPL with the following explicit clarification:
+         This code may be linked against any version of the Qt toolkit
+         from Troll Tech, Norway. $
+   
+   $Revision: 1.10 $
+*/
+
 #include "widget_datanavigator.h"
 #include <qlineedit.h>
 #include <qspinbox.h>
@@ -299,7 +290,7 @@ KDataNavigator::buttonNewClicked()
 }
 
 void
-KDataNavigator::setText(const char* c)
+KDataNavigator::setText(const QString & c)
 {
   // ###########################################################################
   setMode(Manual);
