@@ -1,28 +1,17 @@
 /* -*- C++ -*-
- * This file implements a widget to edit string lists.
- * 
- * the KDE addressbook
- * copyright:  (C) Mirko Sucker, 1998, 1999, 2000
- * mail to:    Mirko Sucker <mirko@kde.org>
- * requires:   recent C++-compiler, at least Qt 2.0
- 
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Library General Public
- License as published by the Free Software Foundation; either
- version 2 of the License, or (at your option) any later version.
- 
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Library General Public License for more details.
- 
- You should have received a copy of the GNU Library General Public License
- along with this library; see the file COPYING.LIB.  If not, write to
- the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- Boston, MA 02111-1307, USA.
- 
- * $Revision: 1.5 $
- */
+   This file implements a widget to edit string lists.
+  
+   the KDE addressbook
+   $ Author: Mirko Boehm $
+   $ Copyright: (C) 1996-2000, Mirko Boehm $
+   $ Contact: mirko@kde.org
+         http://www.kde.org $
+   $ License: GPL with the following explicit clarification:
+         This code may be linked against any version of the Qt toolkit
+         from Troll Tech, Norway. $
+   
+   $Revision: 1.9 $
+*/
   
 #include <qsize.h>
 #include <qbitmap.h>
@@ -87,10 +76,8 @@ QSize StringListEditWidget::sizeHint() const
 {
   // ############################################################################
   float GoldenerSchnitt=2.0/3;
-  const int ButtonSize1=
-    QMAX(buttonNew->sizeHint().width(), buttonUp->sizeHint().width());
-  const int ButtonSize2=
-    QMAX(buttonDown->sizeHint().width(), buttonDelete->sizeHint().width());
+  const int ButtonSize1=QMAX(buttonNew->sizeHint().width(), buttonUp->sizeHint().width());
+  const int ButtonSize2=QMAX(buttonDown->sizeHint().width(), buttonDelete->sizeHint().width());
   const int Grid=3, ButtonSize=QMAX(ButtonSize1, ButtonSize2);
   int cx, cy; 
   // -----
@@ -114,11 +101,10 @@ void StringListEditWidget::resizeEvent(QResizeEvent*)
   const int ButtonSize2=
     QMAX(buttonDown->sizeHint().width(), buttonDelete->sizeHint().width());
   const int Grid=3, ButtonSize=QMAX(ButtonSize1, ButtonSize2);
-  QPushButton* buttons[]= {
+  QPushButton* buttons[]= {   
     buttonUp, 
-    buttonDown,
-    buttonDelete
-  };
+      buttonDown,
+      buttonDelete };
   const int Size=sizeof(buttons)/sizeof(buttons[0]);
   int i, j, h, tempx, tempy;
   // -----
@@ -278,13 +264,16 @@ void StringListEditWidget::itemChanged(const QString& text)
 {
   // ############################################################################
   static int InProgress; // WORK_TO_DO: check for endless-loop-bug in final 2.1
+  int cursorPos;
   // -----
   if(!lbStrings->count()==0)
     {
-      if(InProgress==0) // avoid endless loop in QT2.1 (possibly qt-copy bug?)
-	{ // this is safe as long as the GUI is single threaded
+      if(InProgress==0) // avoid endless loop
+      	{ // this is safe as long as the GUI is single threaded
 	  InProgress=1;
+	  cursorPos=leLine->cursorPosition();
 	  lbStrings->changeItem(text, lbStrings->currentItem());
+	  leLine->setCursorPosition(cursorPos);
 	  InProgress=0;
 	}
     }
@@ -303,3 +292,4 @@ void StringListEditWidget::enableButtons()
   // ############################################################################
 }
 
+#include "widget_editstringlist.moc"
