@@ -24,6 +24,7 @@
 #include <stdlib.h>
 #include <kdialogbase.h>
 #include <qvalidator.h>
+#include "adddlg.h"
 class QLineEdit;
 
 class TimeValidator :public QValidator 
@@ -39,16 +40,12 @@ class AddTaskDialog : public KDialogBase
   Q_OBJECT
 
   public:
-    AddTaskDialog( QWidget *parent=0, const char *name=0, bool modal=true );
+    AddTaskDialog(QString caption);
     void setTask(const QString &name, long time, long sessionTime );
     QString taskName( void ) const;
     long totalTime( void ) const; 
     long sessionTime( void ) const; 
 
-  protected slots:
-    virtual void slotCancel( void );
-    virtual void slotOk( void );
-
   signals:
     /** 
      * raised on click of OK or Cancel.
