@@ -1,5 +1,5 @@
 ;/*
-    $Id: kcalc_core.cpp,v 1.29 2000/04/30 06:34:07 waba Exp $
+    $Id: kcalc_core.cpp,v 1.31 2000/08/01 16:06:39 bieker Exp $
 
     kCalculator, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -43,13 +43,6 @@
 #include "dlabel.h"
 #include "kcalc.h"
 
-// Undefine HAVE_LONG_DOUBLE for Beta 4 since RedHat 5.0 comes with a borken
-// glibc
-
-//#ifdef HAVE_LONG_DOUBLE
-//#undef HAVE_LONG_DOUBLE
-//#endif
-
 #ifndef HAVE_FUNC_ISINF
 #ifdef HAVE_IEEEFP_H
 #include <ieeefp.h>
@@ -215,7 +208,7 @@ void QtCalculator::EnterDigit(int data)
 
     QString string;
     string.setNum(data);
-    strcat(display_str,string.data());
+    strcat(display_str,string.ascii());
     DISPLAY_AMOUNT = (CALCAMNT) strtod(display_str,0);
     UpdateDisplay();
     return;
@@ -264,7 +257,7 @@ void QtCalculator::SubtractDigit()
 
     num=num.left(num.length()-1);
     
-    DISPLAY_AMOUNT= strtod((const char*)num ,0);
+    DISPLAY_AMOUNT= strtod(num.ascii() ,0);
 
   }
 
@@ -579,7 +572,7 @@ void QtCalculator::EnterNegate()
 	display_str[pos+1] = '+';
       else{
 	string.insert(pos +1,'-');
-	strncpy(display_str,string.data(),DSP_SIZE);
+	strncpy(display_str,string.ascii(),DSP_SIZE);
       }
     }
     DISPLAY_AMOUNT = (CALCAMNT)strtod(display_str,0);
@@ -1578,11 +1571,11 @@ void QtCalculator::UpdateDisplay()
 
 	if (display_error || str_size < 0) { 
 	  display_error = 1;
-	  strcpy(display_str, i18n("Error"));
+	  strcpy(display_str, i18n("Error").utf8());
 	  if(kcalcdefaults.beep)
 	    QApplication::beep();
 	}
-	calc_display->setText(display_str);
+	calc_display->setText(QString::fromUtf8(display_str));
 
 
   if (inverse){
