@@ -1,7 +1,7 @@
 /*
  * kdfwidget.cpp
  *
- * $Id: kdfwidget.cpp,v 1.19 2000/05/24 09:04:49 kulow Exp $
+ * $Id: kdfwidget.cpp,v 1.20 2000/08/12 22:50:21 faure Exp $
  *
  * Copyright (c) 1998 Michael Kropfberger <michael.kropfberger@gmx.net>
  *
@@ -318,7 +318,7 @@ void KDFWidget::updateDFDone( void )
     QString size, percent;
     if( disk->kBSize() > 0 ) 
     {
-      percent.sprintf("%2.1f%%",disk->percentFull() );
+      percent = KGlobal::locale()->formatNumber(disk->percentFull(), 1) + '%';
       size = disk->prettyKBSize();
     }
     else
