@@ -1,6 +1,6 @@
 /*
 
-    $Id: kedit.h,v 1.48 2000/04/30 05:15:49 waba Exp $
+    $Id: kedit.h,v 1.52 2000/10/11 04:42:01 waba Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -33,13 +33,14 @@
 #include "print.h"
 #include "version.h"
 
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 #include <keditcl.h>
 
 class COptionDialog;
 class KSpell;
 class QTimer;
 class KRecentFilesAction;
+class KToggleAction;
 class KURL;
 namespace KIO { class Job; }
 
@@ -48,7 +49,7 @@ namespace KIO { class Job; }
 #define ID_INS_OVR 2
 #define ID_GENERAL 3
 
-class TopLevel : public KTMainWindow
+class TopLevel : public KMainWindow
 {
     Q_OBJECT
 
@@ -61,7 +62,8 @@ public:
 
     enum { OPEN_READWRITE 	= 1,
 	   OPEN_READONLY 	= 2,
-	   OPEN_INSERT 		= 4 };
+	   OPEN_INSERT 		= 4,
+	   OPEN_NEW             = 8 };
 
     TopLevel( QWidget *parent=0, const char *name=0 );
     ~TopLevel();
@@ -130,12 +132,10 @@ private:
     QString url_location;
     QTimer *statusbar_timer;
     KRecentFilesAction *recent;
+    KToggleAction *statusbarAction;
+    KToggleAction *toolbarAction;
 
     int open_mode;
-    int editor_width;
-    int editor_height;
-    int show_toolbar;
-    int show_statusbar;
     struct printinfo pi;
 
     SOptionState mOptionState;
@@ -194,7 +194,7 @@ public slots:
     void spellcheck();
     void spell_started ( KSpell *);
     void spell_progress (unsigned int percent);
-    void spell_done(const char *);
+    void spell_done(const QString&);
     void spell_finished();
 
     void urlDrop_slot(QDropEvent* e);
