@@ -1,7 +1,7 @@
 
 /*
 
-    $Id: floppy.cpp,v 1.21 2000/05/24 09:04:49 kulow Exp $
+    $Id: floppy.cpp,v 1.30 2000/10/01 15:47:36 pfeiffer Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben   
                        wuebben@math.cornell.edu
@@ -22,25 +22,26 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
     */
+
+
 #include "floppy.h"
 #include "floppy.moc"
 
+#include <iostream.h>
+#include <qlayout.h>
+#include <qlabel.h>
+#include <qpushbutton.h>
+#include <qcombobox.h>
+
+
 #include <kconfig.h>
 #include <kglobal.h>
 #include <kstddirs.h>
 #include <kmessagebox.h>
 
-extern "C" {
-int  check_if_mounted(const char *file, int *mount_flags);
-}
 
-FloppyData::FloppyData
-(
-	QWidget* parent,
-	const char* name
-)
-	:
-	QWidget( parent, name )
+FloppyData::FloppyData(QWidget * parent, const char * name)
+ : KDialog( parent, name )
 {
 
         proc = 0L;
@@ -51,107 +52,113 @@ FloppyData::FloppyData
 	tracks = 0;
 	blocks = 0;
 
-        outerframe = new QGroupBox(this,"box");
-	outerframe->setGeometry(5,5,350,360);
-	outerframe->setFrameStyle(QFrame::Box|QFrame::Sunken);
+        QVBoxLayout* ml = new QVBoxLayout( this, 10 );
+
+        QHBoxLayout* h1 = new QHBoxLayout( ml );
+
+        QVBoxLayout* v1 = new QVBoxLayout( h1 );
+        h1->addSpacing( 5 );
+
+        QGridLayout* g1 = new QGridLayout( v1, 3, 2 );
 
         label1 = new QLabel(this);
 	label1->setText(i18n("Floppy Drive:"));
-	label1->setGeometry( 20, 20, 130, 25 );
+        g1->addWidget( label1, 0, 0, AlignLeft );
 
 
 	deviceComboBox = new QComboBox( FALSE, this, "ComboBox_1" );
-	deviceComboBox->setGeometry( 120, 20, 100, 25 );
-	deviceComboBox->setAutoResize( FALSE );
+	g1->addWidget( deviceComboBox, 0, 1, AlignLeft );
 
         label2 = new QLabel(this);
 	label2->setText(i18n("Density:"));
-	label2->setGeometry( 20, 55, 130, 25 );
-
+        g1->addWidget( label2, 1, 0, AlignLeft );
 
 	densityComboBox = new QComboBox( FALSE, this, "ComboBox_1" );
-	densityComboBox->setGeometry( 120, 55, 100, 25 );
-	densityComboBox->setAutoResize( FALSE );
+	g1->addWidget( densityComboBox, 1, 1, AlignLeft );
 
         label3 = new QLabel(this);
 	label3->setText(i18n("File System:"));
-	label3->setGeometry( 20,90, 130, 25 );
+        g1->addWidget( label3, 2, 0, AlignLeft );
 
  	filesystemComboBox = new QComboBox( FALSE, this, "ComboBox_2" );
-	filesystemComboBox->setGeometry( 120, 90, 100, 25 );
-	filesystemComboBox->setAutoResize( FALSE );
-	connect(filesystemComboBox,SIGNAL(activated(int)),
-		this,SLOT(filesystemchanged(int)));
-	
-	quitbutton = new QPushButton( this, "PushButton_1" );
-	quitbutton->setGeometry( 240, 40, 100, 25 );
-	quitbutton->setText(i18n( "Quit") );
-	quitbutton->setAutoRepeat( FALSE );
-	quitbutton->setAutoResize( FALSE );
-	connect(quitbutton,SIGNAL(clicked()),this,SLOT(quit()));
+	g1->addWidget( filesystemComboBox, 2, 1, AlignLeft );
 
-	aboutbutton = new QPushButton( this, "PushButton_2" );
-	aboutbutton->setGeometry( 240, 75, 100, 25 );
-	aboutbutton->setText( i18n("About") );
-	aboutbutton->setAutoRepeat( FALSE );
-	aboutbutton->setAutoResize( FALSE );
-	connect(aboutbutton,SIGNAL(clicked()),this,SLOT(about()));
+        v1->addSpacing( 10 );
 
-	helpbutton = new QPushButton( this, "PushButton_1" );
-	helpbutton->setGeometry( 240, 165, 100, 25 );
-	helpbutton->setText(i18n( "Help") );
-	helpbutton->setAutoRepeat( FALSE );
-	helpbutton->setAutoResize( FALSE );
-	connect(helpbutton,SIGNAL(clicked()),this,SLOT(help()));
-
-
-
-	formatbutton = new QPushButton( this, "PushButton_3" );
-	formatbutton->setGeometry( 240, 200, 100, 25 );
-	formatbutton->setText(i18n( "Format") );
-	formatbutton->setAutoRepeat( FALSE );
-	formatbutton->setAutoResize( FALSE );
-	connect(formatbutton,SIGNAL(clicked()),this,SLOT(format()));
-
-
-	progress = new KProgress( this, "Progress" );
-	progress->setGeometry( 20, 325, 320, 30 );
-	progress->setFont(QFont("Helvetica",12,QFont::Normal));
-	progress->setBarColor(QApplication::winStyleHighlightColor());
-
-	frame = new QLabel( this, "NewsWindow" );
-	frame->setGeometry( 20, 275, 320, 38 );
-	frame->setFrameStyle(QFrame::Panel | QFrame::Sunken);
-	frame->setAlignment(AlignCenter|WordBreak|ExpandTabs);
-	
-	buttongroup = new QButtonGroup( this, "ButtonGroup_1" );
-	buttongroup->setGeometry( 20, 125, 200, 135 );
+        buttongroup = new QButtonGroup( this, "ButtonGroup_1" );
 	buttongroup->setFrameStyle( 49 );
-	buttongroup->setAlignment( 1 );
+	v1->addWidget( buttongroup );
+
+        QVBoxLayout* v2 = new QVBoxLayout( buttongroup, 10 );
 
 	quick = new QRadioButton( buttongroup, "RadioButton_2" );
-	quick->setGeometry( 15, 10, 170, 30 );
 	quick->setText(i18n( "Quick Erase") );
-	quick->setAutoResize( TRUE );
+        v2->addWidget( quick, AlignLeft );
 
 	fullformat = new QRadioButton( buttongroup, "RadioButton_3" );
-	fullformat->setGeometry( 15, 40, 170, 30 );
 	fullformat->setText(i18n( "Full Format") );
-	fullformat->setAutoResize( TRUE );
 	fullformat->setChecked(TRUE);
+        v2->addWidget( fullformat, AlignLeft );
 
-	labellabel = new QCheckBox( this, "RadioButton_4" );
-	labellabel->setGeometry( 35, 195, 170, 30 );
+	verifylabel = new QCheckBox( buttongroup, "RadioButton_4" );
+	verifylabel->setText(i18n( "Verify on" ));
+	verifylabel->setChecked(TRUE);
+	v2->addWidget( verifylabel, AlignLeft );
+
+	labellabel = new QCheckBox( buttongroup, "RadioButton_4" );
 	labellabel->setText(i18n( "Create Label:") );
-	labellabel->setAutoResize( TRUE );
 	labellabel->setChecked(TRUE);
+        v2->addWidget( labellabel, AlignLeft );
 
-	lineedit = new QLineEdit( this, "Lineedit" );
-	lineedit->setGeometry( 35, 225, 170, 25 );
+        QHBoxLayout* h2 = new QHBoxLayout( v2 );
+        h2->addSpacing( 20 );
+
+	lineedit = new QLineEdit( buttongroup, "Lineedit" );
 	lineedit->setText(i18n( "KDE Floppy") );
 	lineedit->setMaxLength(11);
+        lineedit->setMinimumWidth( lineedit->sizeHint().width() );
+        h2->addWidget( lineedit, AlignRight );
 
+        QVBoxLayout* v3 = new QVBoxLayout( h1 );
+	
+	quitbutton = new QPushButton( this, "PushButton_1" );
+	quitbutton->setText(i18n( "&Quit") );
+	quitbutton->setAutoRepeat( FALSE );
+	connect(quitbutton,SIGNAL(clicked()),this,SLOT(quit()));
+	 v3->addWidget( quitbutton );
 
+	aboutbutton = new QPushButton( this, "PushButton_2" );
+	aboutbutton->setText( i18n("&About...") );
+	aboutbutton->setAutoRepeat( FALSE );
+	connect(aboutbutton,SIGNAL(clicked()),this,SLOT(about()));
+        v3->addWidget( aboutbutton );
+        v3->addStretch( 1 );
+
+	helpbutton = new QPushButton( this, "PushButton_4" );
+	helpbutton->setText(i18n( "&Help") );
+	helpbutton->setAutoRepeat( FALSE );
+	connect(helpbutton,SIGNAL(clicked()),this,SLOT(help()));
+        v3->addWidget( helpbutton );
+
+	formatbutton = new QPushButton( this, "PushButton_3" );
+	formatbutton->setText(i18n( "&Format") );
+	formatbutton->setAutoRepeat( FALSE );
+	connect(formatbutton,SIGNAL(clicked()),this,SLOT(format()));
+        v3->addWidget( formatbutton );
+
+        ml->addSpacing( 10 );
+
+	frame = new QLabel( this, "NewsWindow" );
+	frame->setMinimumHeight( 30 );
+	frame->setFrameStyle(QFrame::Panel | QFrame::Sunken);
+	frame->setAlignment(AlignCenter|WordBreak|ExpandTabs);
+        ml->addWidget( frame );
+	
+	progress = new KProgress( this, "Progress" );
+	progress->setFont(QFont("Helvetica",12,QFont::Normal));
+	progress->setBarColor(QApplication::winStyleHighlightColor());
+        progress->setMinimumHeight( 30 );
+        ml->addWidget( progress );
 
 	mytimer = new QTimer;
 	connect(mytimer,SIGNAL(timeout()),this,SLOT(cf2done()));
@@ -162,25 +169,26 @@ FloppyData::FloppyData
 	errtimer = new QTimer;
 	connect(errtimer,SIGNAL(timeout()),this,SLOT(errslot()));
 
-	setCaption(i18n("KDE Floppy Formatter"));
-
 	addDevice(FLOPPYA3);
 	addDevice(FLOPPYA5);
 	addDevice(FLOPPYB3);
 	addDevice(FLOPPYB5);
 	addDensity(i18n("HD"));	
 	addDensity(i18n("DD"));	
-	addFileSystem("Dos");
-	addFileSystem("ext2fs");
+	addFileSystem(i18n("Dos"));
+	addFileSystem(i18n("ext2fs"));
 
 	readSettings();
 	setWidgets();
 
-	if(!findExecutables())
-	  formatbutton->setEnabled(FALSE);
+	findExecutables();
 
-	resize( 360, 370 );
-	setFixedSize(360,370);
+    int maxW = QMAX( deviceComboBox->sizeHint().width(), 
+                     densityComboBox->sizeHint().width() );
+    maxW = QMAX( maxW, filesystemComboBox->sizeHint().width() );
+    deviceComboBox->setMinimumWidth( maxW );
+    densityComboBox->setMinimumWidth( maxW );
+    filesystemComboBox->setMinimumWidth( maxW );
 }
 
 
@@ -194,40 +202,35 @@ void FloppyData::closeEvent(QCloseEvent*){
    
 }
 
-void FloppyData::addDevice(const char* name){
-
+void FloppyData::show() {
+  setCaption(i18n("KDE Floppy Formatter"));
+  KDialog::show();
+}
 
+void FloppyData::addDevice(const QString & name)
+{
   deviceComboBox->insertItem(name);
 }
 
-
-
-void FloppyData::addDensity(const char* name){
-
-
+void FloppyData::addDensity(const QString & name)
+{
   densityComboBox->insertItem(name);
 }
 
-
-
-void FloppyData::addFileSystem(const char* name){
-
+void FloppyData::addFileSystem(const QString & name)
+{
   filesystemComboBox->insertItem(name);
-
 }
 
-
 bool FloppyData::findDevice()
 {
-
-
   if( deviceComboBox->currentText() == FLOPPYA3 ){
     if( densityComboBox->currentText() == i18n( "HD")){
       device = "/dev/fd0H1440";
       blocks = 1440;
       tracks = 80;
-      mdev = "/dev/fd0";
-      if( access(device.data(),W_OK) < 0){
+      //mdev = "/dev/fd0";
+      if( access(QFile::encodeName(device),W_OK) < 0){
 	device = "/dev/fd0u1440";
       }
     }
@@ -235,8 +238,8 @@ bool FloppyData::findDevice()
       device = "/dev/fd0D720";
       blocks = 720;
       tracks = 80;
-      mdev = "/dev/fd0";
-      if( access(device.data(),W_OK) < 0){
+      //mdev = "/dev/fd0";
+      if( access(QFile::encodeName(device),W_OK) < 0){
 	device = "/dev/fd0u720";
       }
     }
@@ -247,13 +250,13 @@ bool FloppyData::findDevice()
       device = "/dev/fd0h1200";
       blocks = 1200;
       tracks = 80;
-      mdev = "/dev/fd0";
+      //mdev = "/dev/fd0";
     }
     else{
       device = "/dev/fd0h360";
       blocks = 720;
       tracks = 40;
-      mdev = "/dev/fd0";
+      //mdev = "/dev/fd0";
     }
   }
 
@@ -262,8 +265,8 @@ bool FloppyData::findDevice()
       device = "/dev/fd1H1440";
       blocks = 1400;
       tracks = 80;
-      mdev = "/dev/fd1";
-      if(access(device.data(),W_OK) < 0){
+      //mdev = "/dev/fd1";
+      if(access(QFile::encodeName(device),W_OK) < 0){
 	device = "/dev/fd1u1440";
       }
     }
@@ -271,8 +274,8 @@ bool FloppyData::findDevice()
       device = "/dev/fd1D720";
       blocks = 720;
       tracks = 80;
-      mdev = "/dev/fd1";
-      if( access(device.data(),W_OK) < 0){
+      //mdev = "/dev/fd1";
+      if( access(QFile::encodeName(device),W_OK) < 0){
 	device = "/dev/fd1u720";
     }
     }
@@ -283,25 +286,25 @@ bool FloppyData::findDevice()
       device = "/dev/fd1h1200";
       blocks = 1200;
       tracks = 80;
-      mdev = "/dev/fd1";
+      //mdev = "/dev/fd1";
     }
     else{
       device = "/dev/fd1h720";
       blocks = 720;
       tracks = 80;
-      mdev = "/dev/fd1";
+      //mdev = "/dev/fd1";
     }
   }
 
 
-  if( access(device.data(),W_OK) < 0){
+  if( access(QFile::encodeName(device),W_OK) < 0){
 
     QString str = i18n(
 	      "Cannot access %1\nMake sure that the device exists and that\n"
 	      "you have write permission to it.").arg(device);
     KMessageBox::error(this, str);
 
-    formatbutton->setEnabled(FALSE);
+    //formatbutton->setEnabled(FALSE);
     return false;
 
   }
@@ -309,61 +312,31 @@ bool FloppyData::findDevice()
   return true;
 }
 
-bool FloppyData::findExecutables(){
-
-
-  bool mkformat = false;
-  bool mkdosfs  = false;
-  bool mke2fs   = false;
-  bool ok 	= true;
-  
-  if (KGlobal::dirs()->findExe("kfdformat").length()) {
-    mkformat = true;
-  }
-  if (KGlobal::dirs()->findExe("kmke2fs").length()) {
-    mke2fs = true;
-  }
-  if (KGlobal::dirs()->findExe("kmkdosfs").length()) {
-    mkdosfs = true;
+void FloppyData::findExecutables()
+{
+  QString path = getenv("PATH");
+  path.append(":/usr/sbin:/sbin");
+ 
+  fdformat = KGlobal::dirs()->findExe("fdformat", path);
+  mke2fs = KGlobal::dirs()->findExe("mke2fs", path);
+  mkdosfs = KGlobal::dirs()->findExe("mkdosfs", path);
+  QString str = "";
+  if (fdformat.isEmpty()) {
+    str = i18n("Cannot find fdformat.");
   }
 
-  if(!mkformat){
+  if (mke2fs.isEmpty()) {
+    str = i18n("Cannot find mke2fs");
+  }
 
-    QString str = i18n(
-       	"Cannot find kfdformat\nkfdformat is part of the KFloppy distribution.\n"
-	"Please install KFloppy properly.");
-    KMessageBox::error(this, str);
+  if (mkdosfs.isEmpty()) {
+    str = i18n("Cannot find mkdosfs");
+  }
 
+  if (str != "") {
     formatbutton->setEnabled(FALSE);
-    ok = false;
-
-  }
-
-  if( !mke2fs){
-    QString str = i18n(
-          "Cannot find kmke2fs\nkmke2fs is part of the KFloppy distribution.\n"
-	  "Please install KFloppy properly.");
     KMessageBox::error(this, str);
-
-    formatbutton->setEnabled(FALSE);
-    ok = false;
   }
-
-  if( !mkdosfs){
-
-    QString str = i18n(
-		"Cannot find kmkdosfs\nkmkdosfs is part of the KFloppy distribution.\n"
-		"Please install KFloppy properly.");
-    KMessageBox::error(this, str);
-
-    formatbutton->setEnabled(FALSE);
-    ok = false;
-
-  }
-
-
-  return ok;
-
 }
 
 void FloppyData::quit(){
@@ -390,7 +363,7 @@ void FloppyData::reset(){
   proc = 0L;
   progress->setValue(0);
   frame->clear();
-  formatbutton->setText(i18n("Format"));
+  formatbutton->setText(i18n("&Format"));
 
 }
 
@@ -398,7 +371,7 @@ void FloppyData::format(){
 
   errstring = "";
   formatstring ="";
-  mdev = "";
+  //mdev = "";
 
   if(formating){
     abort = true;
@@ -406,19 +379,13 @@ void FloppyData::format(){
     return;
   }
 
-  formatbutton->setText(i18n("Abort"));
+  formatbutton->setText(i18n("A&bort"));
 
   if(!findDevice()){
     reset();
     return;
   }
 
-  if(!checkmount()){
-    reset();
-    return;
-  }
-
-
   if(quick->isChecked()){
     quickerase = true;
     formating = false;
@@ -426,19 +393,20 @@ void FloppyData::format(){
     return;
   }
 
-
+  frame->setText(i18n("Formatting ..."));
   badblocks = 0;
   abort = false;
   formating = true;
-  progress->setRange(0,tracks);
+  progress->setRange(0,tracks*2);
   progress->setValue(0);
   counter = 0;
 
   proc = new KProcess;
-
-  proc->setExecutable("kfdformat");
-  *proc << "-n" << device.data();
-
+  *proc << fdformat;
+  if (!verifylabel->isChecked()) {
+    *proc << "-n";
+  }
+  *proc << device;
 
   connect(proc, SIGNAL(processExited(KProcess *)),this, SLOT(formatdone(KProcess*)));
 
@@ -472,24 +440,14 @@ void FloppyData::formatdone(KProcess*){
 
 }
 
-void FloppyData::readStdout(KProcess *, char *buffer, int buflen){
+void FloppyData::readStdout(KProcess *, char *buffer, int buflen)
+{
+  bool increment = true;
 
-  char mybuffer[1001];
-  int amount;
-  bool  increment = true;
+  formatstring = QString::fromLocal8Bit(buffer, buflen);
 
-  if(buflen > 1000)
-    amount = 1000;
-  else
-    amount = buflen;
-
-  memcpy(mybuffer,buffer,amount);
-  mybuffer[amount] = '\0';
-
-  formatstring = mybuffer;
-
-
-  if(formatstring.contains("track")){
+  if (formatstring.contains("track"))
+  {
     int pos = formatstring.find('\n');
     QString newstring;
 
@@ -503,7 +461,8 @@ void FloppyData::readStdout(KProcess *, char *buffer, int buflen){
   }
 
 
-  if(increment){
+  if (increment)
+  {
     counter ++;
     progress->setValue(counter);     
   }
@@ -593,14 +552,14 @@ printf("NEWLINE:%s\n",mystring.data());
 #endif
 
     if(findKeyWord(mystring,"BBF ")){
-      int bblock = atoi(mystring.left(8).data());
+      int bblock = mystring.left(8).toInt();
       QString mstr;
       mstr = i18n("Block %1 is bad. Continuing ...").arg(bblock);
       frame->setText(mstr);
     }
 
     if(findKeyWord(mystring,"TNBB ")){
-      badblocks = atoi(mystring.left(8).data());
+      badblocks = mystring.left(8).toInt();
     }
     newstring = newstring.mid(i+1,newstring.length());
   }
@@ -643,8 +602,30 @@ void FloppyData::readfsStderr(KProcess *, char *buffer, int buflen){
   memcpy(mybuffer,buffer,amount);
   mybuffer[amount] = '\0';
 
+  // skip version message
+  int pos=0;
+  if (fserrstring.isEmpty() && strncmp(mybuffer, "mke2fs", 6) == 0)
+    {
+      pos = QString(mybuffer).find('\n');
+      //printf("pos=%d, len=%d\n", pos, amount);
+      if (pos+1 == amount)
+	return;
+      pos++;
+    }
+  if (fserrstring.isEmpty() && strncmp(mybuffer, "/sbin/mkdosfs", 13) == 0)
+    {
+      pos = QString(mybuffer).find('\n');
+      //printf("pos=%d, len=%d\n", pos, amount);
+      if (pos+1 == amount)
+	return;
+      pos++;
+    }
+
+  printf("ERR: <%s>\n", mybuffer);
+  printf("pos=%d, len=%d\n", pos, amount);
+
   abort = true;
-  fserrstring += mybuffer;
+  fserrstring += mybuffer+pos;
 
   // the timers are put in so that I get all of the error message.
   fserrtimer->start(300,true);
@@ -701,7 +682,7 @@ void FloppyData::cf2done(){
 
   if(!lcquick){
     QString str = i18n(
-		"The floppy was sucessfully formatted.\n"
+		"The floppy was successfully formatted.\n"
 		"Blocks marked bad: %1\n"
 		"Raw Capacity: %2\n")
 		.arg(badblocks)
@@ -710,13 +691,13 @@ void FloppyData::cf2done(){
     KMessageBox::information(this, str);
   }
   else{
-    QString str = i18n("All files were sucessfully erased.");
+    QString str = i18n("All files were successfully erased.");
 
     KMessageBox::information(this, str);
   }
 }
 
-int FloppyData::findKeyWord(QString& string,const char* word){
+int FloppyData::findKeyWord(QString & string,const QString & word){
 
   int count = 0;
   int index = 0;
@@ -725,75 +706,37 @@ int FloppyData::findKeyWord(QString& string,const char* word){
   QString wordstring = word;
   len = wordstring.length();
     
-  while( (index = string.find(word)) >= 0){
-
-    count ++;
+  while( (index = string.find(word)) >= 0)
+  {
+    count++;
     string = string.mid(index + len,string.length());
-
   }
 
   return count;
-
 }
 
-
-void FloppyData::createfilesystem(){
-
+void FloppyData::createfilesystem()
+{
   fsstring = "";
   fserrstring = "";
 
-  if(quickerase){
-    if(!findDevice())
-      return;
-    quickerase = true;
-  }
-
-  if(quickerase)
-    progress->setRange(0,3);
-  else
-    progress->setRange(0,blocks/16);
-
-
-  if(quickerase)
-    counter = 1;	
-  else
-    counter = 0;
-
-  progress->setValue(counter);
-
-  if(quickerase){
-
-    frame->setText(i18n("Creating Filesystem ..."));
-  }
-  else{
-
-    frame->setText(i18n("Verifying ..."));
-
-  }
+  frame->setText(i18n("Creating Filesystem ..."));
 
   proc = new KProcess;
 
-  if((QString)filesystemComboBox->currentText() == "Dos"){
+  if (filesystemComboBox->currentText() == i18n("Dos")){
 
-    proc->setExecutable("kmkdosfs");
-    if(!quickerase)
-      
-      *proc << "-c" ;
-
-    if(labellabel->isChecked())
-      *proc << "-n" <<lineedit->text();
-
-    *proc << device.data();
+        *proc << mkdosfs;
+	if(labellabel->isChecked())
+	  *proc << "-n" <<lineedit->text();
+	*proc << device;
   }
   else{
 
-    proc->setExecutable("kmke2fs");
-
-    if(!quickerase)
-      *proc << "-c" ;
-
-    *proc << device.data();
-
+    *proc << mke2fs;
+    if(labellabel->isChecked())
+      *proc << "-L" <<lineedit->text();
+    *proc << device;
   }
 
 
@@ -815,43 +758,10 @@ void FloppyData::createfilesystem(){
     proc = 0L;
     progress->setValue(0);
   }
-
-
 }
 
 
 
-bool FloppyData::checkmount(){
-
-  int		retval;
-  int		mount_flags;
-
-
-  retval = check_if_mounted(mdev.data(), &mount_flags);
-  if (retval) {
-    KMessageBox::error(this,
-		      i18n(
-		      "Error while trying to determine whether floppy is mounted\n"
-		      )
-			 );
-    return false;
-  }
-
-
-  if (!(mount_flags & EXT2_MF_MOUNTED)){
-   return true;
-  }
-
-
-
-
-  QString str = i18n("%1 is mounted.\nPlease unmount the floppy first.")
-	        .arg(mdev);
-  KMessageBox::error(this, str);  
-
-  return false;
-}
-
 void FloppyData::about(){
 
   QDialog *dlg = new MyAbout(0);
@@ -866,7 +776,6 @@ void FloppyData::about(){
   dlg->exec();
   delete dlg;
 
-
 }
 
 
@@ -898,6 +807,8 @@ void FloppyData::writeSettings(){
 
 	labelconfig = labellabel->isChecked();
 
+	verifyconfig = verifylabel->isChecked();
+
 	config->writeEntry("CreateLabel",labelconfig);
 	config->writeEntry("Label",labelnameconfig);
 
@@ -906,6 +817,7 @@ void FloppyData::writeSettings(){
 	config->writeEntry("FloppyDrive",driveconfig);
 	config->writeEntry("Density",densityconfig);
 	config->writeEntry("Filesystem",filesystemconfig);
+	config->writeEntry("Verify",verifyconfig);
 	config->sync();
 
 }
@@ -915,12 +827,13 @@ void FloppyData::readSettings(){
         config = kapp->config();
 	config->setGroup("GeneralData");
 
+	verifyconfig = config->readNumEntry("Verify", 1);
 	labelconfig = config->readNumEntry("CreateLabel",1);
 	labelnameconfig = config->readEntry("Label","KDE Floppy");
 	quickformatconfig = config->readNumEntry("QuickFormat",0);
 	driveconfig = config->readEntry("FloppyDrive","A: 3.5");
-	densityconfig = config->readEntry("Density","HD");
-	filesystemconfig = config->readEntry("Filesystem","Dos");
+	densityconfig = config->readEntry("Density",i18n("HD"));
+	filesystemconfig = config->readEntry("Filesystem",i18n("Dos"));
 
 }
 
@@ -934,6 +847,13 @@ void FloppyData::setWidgets(){
     labellabel->setChecked(FALSE);
   }
 
+  if(verifyconfig) {
+    verifylabel->setChecked(TRUE);
+  }
+  else {
+    verifylabel->setChecked(FALSE);
+  }
+
   if(quickformatconfig){
     quick->setChecked(TRUE);
     fullformat->setChecked(FALSE);
@@ -961,29 +881,6 @@ void FloppyData::setWidgets(){
       densityComboBox->setCurrentItem(i);
     }
   }
-
-  if((QString) filesystemComboBox->currentText() == (QString) "ext2fs"){
-    labellabel->setEnabled(FALSE);
-    lineedit->setEnabled(FALSE);
-  }
-
 }
 
-void  FloppyData::filesystemchanged(int index){
 
-
-  if ((QString)filesystemComboBox->text(index) == (QString)"ext2fs"){
-
-    labellabel->setEnabled(FALSE);
-    lineedit->setEnabled(FALSE);
-
-  }
-  else{
-
-    labellabel->setEnabled(TRUE);
-    lineedit->setEnabled(TRUE);
-
-  }
-
-
-}
