@@ -49,7 +49,7 @@
 
 #include "optiondialog.h"
 
-
+#if 0
 #include <qobjectlist.h>
 static void enableWidget( QWidget *w, bool state )
 {
@@ -67,8 +67,7 @@ static void enableWidget( QWidget *w, bool state )
   }
   w->setEnabled( state );
 }
-
-
+#endif
 
 
 
@@ -285,7 +284,7 @@ void COptionDialog::setupColorPage( void )
   QString text;
   QFrame *page = addPage( i18n("Colors"), 
     i18n("Editor colors. System selection color is always used"), 
-    BarIcon("colors", KIcon::SizeMedium ) );
+    BarIcon("colorize", KIcon::SizeMedium ) );
 
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
@@ -383,7 +382,7 @@ void COptionDialog::setupFilePage( void )
 {
   QString text;
   QFrame *page = addPage( i18n("Files"), i18n("File management"),
-			  BarIcon("files", KIcon::SizeMedium ) );
+			  BarIcon("kmultiple", KIcon::SizeMedium ) );
 
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
@@ -452,7 +451,7 @@ void COptionDialog::setupMiscPage( void )
   QLabel *label;
   
   QFrame *page = addPage( i18n("Miscellaneous"), i18n("Various properties"),
-			  BarIcon("misc", KIcon::SizeMedium ) );
+			  BarIcon("gear", KIcon::SizeMedium ) );
 
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
@@ -749,8 +748,8 @@ void COptionDialog::slotApply( void )
       f.useSystemFont = mFont.checkSystem->isChecked();
       f.localFont = mFont.chooser->font();
 
-      const char *nonPrintText = mFont.nonPrintInput->text(); 
-      if( nonPrintText == 0 || strlen(nonPrintText) == 0 )
+      QString nonPrintText = mFont.nonPrintInput->text(); 
+      if( nonPrintText.isEmpty() )
       {
 	f.nonPrintChar = ' ';
       }
@@ -874,7 +873,7 @@ void COptionDialog::setFont( SDisplayFont &font )
 
   mFont.checkSystem->setChecked( font.useSystemFont );
   mFont.chooser->setFont( font.localFont, true );
-  char buf[2] = { font.nonPrintChar, 0 };
+  QString buf = font.nonPrintChar;
   mFont.nonPrintInput->setText( buf );
 }
 
@@ -1127,3 +1126,4 @@ int CColorListItem::width(const QListBox *lb ) const
 
 
 
+#include "optiondialog.moc"
