@@ -37,6 +37,7 @@
 #include <kconfig.h>
 #include <kfiledialog.h>
 #include <klocale.h>
+#include <kglobal.h>
 #include <kmessagebox.h>
 #include <kstddirs.h>
 
@@ -311,51 +312,46 @@ void CPrinterDialog::writeConfiguration( void )
 }
 
 
-const char *CPrinterDialog::headerText( uint index )
+QString CPrinterDialog::headerText( uint index )
 {
-  static const char *text[4] = {"None","DateTime","PageNumber","FileName"};
+  static const QString text[4] = {"None","DateTime","PageNumber","FileName"};
   return( text[ index > 3 ? 0 : index ] );
 }
 
 
-int CPrinterDialog::headerTextIndex( const char *headerText )
+int CPrinterDialog::headerTextIndex( const QString & headerText )
 {
-  static const char *text[4] = {"None","DateTime","PageNumber","FileName"};
+  static const QString text[4] = {"None","DateTime","PageNumber","FileName"};
   if( headerText != 0 )
   {
     for( int i=0; i<4; i++ )
     {
-      if( strcmp( headerText, text[i] ) == 0 ) { return( i ); }
+      if( headerText == text[i] ) { return( i ); }
     }
   }  
   return( 0 );
 }
 
 
-const char *CPrinterDialog::headerLine( uint index )
+QString CPrinterDialog::headerLine( uint index )
 {
-  static const char *text[3] = {"None","SingleLine","Rectangle"};
+  static const QString text[3] = {"None","SingleLine","Rectangle"};
   return( text[ index > 2 ? 0 : index ] );
 }
 
 
-int CPrinterDialog::headerLineIndex( const char *headerLine )
+int CPrinterDialog::headerLineIndex( const QString & headerLine )
 {
-  static const char *text[3] = {"None","SingleLine","Rectangle"};
+  static const QString text[3] = {"None","SingleLine","Rectangle"};
   if( headerLine != 0 )
   {
     for( int i=0; i<3; i++ )
     {
-      if( strcmp( headerLine, text[i] ) == 0 ) { return( i ); }
+      if( headerLine == text[i] ) { return( i ); }
     }
   }  
   return( 0 );
 }
-  
-
-
-
-
 
 void CPrinterDialog::setupDestinationPage( void )
 {
@@ -750,13 +746,13 @@ void CPrinterDialog::setupLayoutPage( void )
   name[2] = i18n("Right");
   name[3] = i18n("Border");
 
-  QStrList textList;
+  QStringList textList;
   textList.append(i18n("None"));
   textList.append(i18n("Date and time"));
   textList.append(i18n("Page number"));
   textList.append(i18n("Filename"));
 
-  QStrList lineList;
+  QStringList lineList;
   lineList.append(i18n("None"));
   lineList.append(i18n("Single line"));
   lineList.append(i18n("Rectangle"));
@@ -778,13 +774,13 @@ void CPrinterDialog::setupLayoutPage( void )
 
     if( i<3 )
     {
-      mLayout.headerCombo[i]->insertStrList( &textList );
+      mLayout.headerCombo[i]->insertStringList( textList );
       gbox->addWidget( mLayout.headerLabel[i], 0, i*2, AlignLeft );
       gbox->addWidget( mLayout.headerCombo[i], 1, i*2, AlignLeft );
     }
     else
     {
-      mLayout.headerCombo[i]->insertStrList( &lineList );
+      mLayout.headerCombo[i]->insertStringList( lineList );
       gbox->addWidget( mLayout.headerLabel[i], 3, 0, AlignLeft );
       gbox->addWidget( mLayout.headerCombo[i], 4, 0, AlignLeft );
     }
@@ -824,13 +820,13 @@ void CPrinterDialog::setupLayoutPage( void )
 
     if( i<3 )
     {
-      mLayout.footerCombo[i]->insertStrList( &textList );
+      mLayout.footerCombo[i]->insertStringList( textList );
       gbox->addWidget( mLayout.footerLabel[i], 0, i*2, AlignLeft );
       gbox->addWidget( mLayout.footerCombo[i], 1, i*2, AlignLeft );
     }
     else
     {
-      mLayout.footerCombo[i]->insertStrList( &lineList );
+      mLayout.footerCombo[i]->insertStringList( lineList );
       gbox->addWidget( mLayout.footerLabel[i], 3, 0, AlignLeft );
       gbox->addWidget( mLayout.footerCombo[i], 4, 0, AlignLeft );
     }
@@ -924,13 +920,15 @@ void CPrinterDialog::paperTypeChanged( int id )
   
   if( size.isInch == true )
   {
-    msg = i18n("Size: %1 x %2 inches").arg(size.width,0,'f',1).
-      arg(size.height,0,'f',1);
+    msg = i18n("Size: %1 x %2 inches")
+      .arg(KGlobal::locale()->formatNumber(size.width, 1))
+      .arg(KGlobal::locale()->formatNumber(size.height, 1));
   }
   else
   {
-    msg = i18n("Size: %1 x %2 mm").arg(size.width,0,'f',0).
-      arg(size.height,0,'f',0);
+    msg = i18n("Size: %1 x %2 mm")
+      .arg(KGlobal::locale()->formatNumber(size.width, 0))
+      .arg(KGlobal::locale()->formatNumber(size.height, 0));
   }
 
   mOption.paperSizeLabel->setText( msg ); 
@@ -1338,3 +1336,4 @@ const CPrinterDialog::SPageSize CPrinterDialog::paperSize(
   return( size[ pageSize > QPrinter::Tabloid ? QPrinter::Tabloid : pageSize ]);
   #endif
 }
+#include "printerdialog.moc"
