@@ -21,11 +21,11 @@
 
 #include <qapplication.h>
 #include <qstring.h>
-#include <qstrlist.h>
+#include <qstringlist.h>
 
 #include <kconfig.h>
 
-int readListConf ( KConfig *conf, QString key, QStrList &list )
+int readListConf ( KConfig *conf, QString key, QStringList &list )
 {
   if( !conf->hasKey( key ) )
     { 
@@ -61,7 +61,7 @@ int readListConf ( KConfig *conf, QString key, QStrList &list )
   list.append(value);
 }
 
-void writeListConf ( KConfig *conf, QString key, QStrList &list )
+void writeListConf ( KConfig *conf, QString key, QStringList &list )
 {
   if( list.isEmpty() )
     {
@@ -71,11 +71,12 @@ void writeListConf ( KConfig *conf, QString key, QStrList &list )
   QString str_list;
   QString value;
   int i;
-  for( value = list.first(); value != ""; value = list.next() )
+  for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
     {
+      QString value = *it;
       for( i = 0; i < (int) value.length(); i++ )
 	{
-	  switch( value.data()[i] ) {
+	  switch( value[i].unicode() ) {
 	  case ',':
 	    str_list += '\\';
 	    break;
