@@ -4,8 +4,7 @@
 
 #include <qobject.h>
 #include <qstring.h>
-#include <qtstream.h>
-#include <qmsgbox.h>
+#include <qtextstream.h>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -24,7 +23,7 @@ public:
     ~Data();
 
     bool print();
-    void setPrinter(char* printer);
+    void setPrinter( const QString& printer);
     bool eject();
     bool initialize();
     bool reset();
