@@ -6,12 +6,12 @@
 #include <stdio.h>
 #include <kprocess.h>
 #include <qpopupmenu.h>
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 
 #define ICONWIDTH 24
 #define ICONHEIGHT 24
 
-class Sysload : public KTMainWindow {
+class Sysload : public KMainWindow {
   Q_OBJECT
 public:
   Sysload();
