@@ -11,6 +11,9 @@
 #include <qstring.h>
 #include <qwindowdefs.h>
 #include <qintdict.h>
+
+#include <ksharedptr.h>
+
 #include "svec.h"
 
 enum fields {
@@ -50,8 +53,11 @@ public:
     int inode;
 };
 
-class Procinfo
+class Procinfo : public KShared
 {
+public:
+    typedef KSharedPtr<Procinfo> Ptr;
+    typedef QValueList<Ptr> List;
 public:
     Procinfo(int pid);
     ~Procinfo();
@@ -168,7 +174,6 @@ public:
     Details *details;		// details window or NULL (backlink)
 
     bool selected;	// true if selected in current view
-    bool viewed;	// true if part of current process view
 
     static const int MAX_CMD_LEN;
     static int pagesize;
@@ -348,9 +353,10 @@ class Proc
 {
 public:
     Proc();
+    ~Proc();
     void refresh();
 
-    Svec<Procinfo *> procs;
+    Procinfo::List procs;
     Svec<Category *> cats;
 };
 
@@ -368,8 +374,8 @@ public:
     void remove_cat(int index);
     int findCol(int field);
     
-    Svec<Procinfo *> procs;
-    Svec<Procinfo *> old_procs;
+    Procinfo::List procs;
+    Procinfo::List old_procs;
     Svec<Category *> cats;
     Category *sortcat;
     bool reversed;		// true if sorted backwards
