@@ -1,6 +1,6 @@
 
 /**********************************************************************/
-/*   TimeMon (c)  1994  Helmut Maierhofer			      */
+/*   TimeMon (c)  1994  Helmut Maierhofer                             */
 /*   KDE-ified M. Maierhofer 1998                                     */
 /*   maintained by Dirk A. Mueller <mueller@kde.org>                  */
 /**********************************************************************/
@@ -35,6 +35,17 @@
 #include "timemon.moc"
 #include <stdio.h>
 
+extern "C"
+{
+    KPanelApplet* init(QWidget *parent, const QString& configFile)
+    {
+        KGlobal::locale()->insertCatalogue("ktimemon");
+        KTimeMon *mon = new KTimeMon(configFile, KPanelApplet::Normal,
+                                     KPanelApplet::Preferences, parent, "ktimemon");
+        return mon;
+    }
+}
+
 // Update colour settings with the new ones from the config dialog.
 void KTimeMon::updateConfig(KConfDialog *d)
 {
@@ -53,32 +64,21 @@ void KTimeMon::updateConfig(KConfDialog *d)
 // -----------------------------------------------------------------------------
 // some KPanelApplet API functions
 
-int KTimeMon::widthForHeight(int)
+int KTimeMon::widthForHeight(int height) const
 {
-    return 32;
+    return QMIN((height*3)/4, 24);
 }
 
 
-int KTimeMon::heightForWidth(int)
+int KTimeMon::heightForWidth(int width) const
 {
-    return 32;
+    return QMIN((width*4)/3, 16);
 
 }
 
-void KTimeMon::about()
-{
-    kdDebug() << "about called" << endl;
-}
-
-
-void KTimeMon::help()
-{
-    kdDebug() << "help called" << endl;
-}
-
 void KTimeMon::preferences()
 {
-    kdDebug() << "preferences called" << endl;
+    configure();
 }
 
 
@@ -93,7 +93,7 @@ void KTimeMon::paintEvent(QPaintEvent *)
     w = vertical ? width() : height();
     h = vertical ? height() : width();
 
-    b = (w - 2) / 3;		// bar width (1 pixel gap)
+    b = (w - 2) / 3;            // bar width (1 pixel gap)
 
     x = 0;
 
@@ -105,11 +105,11 @@ void KTimeMon::paintEvent(QPaintEvent *)
         s.fill(h);
 
     QPixmap pixmap(width(), height());
-    pixmap.fill(bgColour);
+    pixmap.fill(this, 0, 0);
 
     QPainter painter(&pixmap);
 
-    if (true) {			// normal mode
+    if (true) {                 // normal mode
         y = h - s.kernel; paintRect(x, y, b, s.kernel, kernelColour, &painter);
         y -= s.user; paintRect(x, y, b, s.user, userColour, &painter);
         y -= s.nice; paintRect(x, y, b, s.nice, niceColour, &painter);
@@ -122,7 +122,7 @@ void KTimeMon::paintEvent(QPaintEvent *)
         x += b + 1;
         y = h - s.sused; paintRect(x, y, b, s.sused, swapColour, &painter);
 
-    } else {			// extended mode
+    } else {                    // extended mode
 
         y = h - s.pout; paintRect(x, y, b, s.pout, kernelColour, &painter);
         y -= s.pin; paintRect(x, y, b, s.pin, niceColour, &painter);
@@ -154,16 +154,17 @@ void KTimeMon::paintRect(int x, int y, int w, int h, QColor c, QPainter *p)
 // Show a tool-tip with some status information.
 void KTimeMon::maybeTip(const QPoint& p)
 {
-    if (!tooltip) return;		// user doesn't want tool tips
-    if (sample == 0) return;	// no associated sample...
+    if (!tooltip) return;               // user doesn't want tool tips
+    if (sample == 0) return;    // no associated sample...
     if(!rect().contains(p)) return;
 
-    QString str;
-
     KSample::Sample s = sample->getSample(100); // scale to 100(%)
-    str.sprintf(i18n("cpu: %lu%% idle\nmem: %luMB %lu%% free\nswap: %luMB %lu%% free"),
-                100-s.kernel-s.user-s.nice, s.used,
-		100-s.used, s.stotal, 100-s.sused);
+    QString str = i18n("cpu: %1% idle\nmem: %2 MB %3% free\nswap: %4 MB %5% free")
+                .arg(100-s.kernel-s.user-s.nice)
+                .arg(KGlobal::locale()->formatNumber(s.used/100.*s.mtotal, 0))
+                .arg(100-s.used)
+                .arg(KGlobal::locale()->formatNumber(s.stotal, 0))
+                .arg(100-s.sused);
 
     tip(rect(), str);
 }
@@ -172,8 +173,9 @@ void KTimeMon::maybeTip(const QPoint& p)
 
 // Initialise the member variables, read the configuration data base,
 // set up the widget, and start the timer.
-KTimeMon::KTimeMon()
-    : KPanelApplet(0, "KTimeMon"), QToolTip(this),
+KTimeMon::KTimeMon(const QString& configFile, Type type, int actions,
+               QWidget *parent, const char *name)
+    : KPanelApplet(configFile, type, actions, parent, name), QToolTip(this),
     configDialog(0), bgProcess(0),
     kernelColour("red1"), userColour("blue"),
     niceColour("yellow"), cachedColour("darkgreen"),
@@ -184,9 +186,7 @@ KTimeMon::KTimeMon()
     mouseAction[1] = NOTHING;
     mouseAction[2] = MENU;
 
-    KConfig* conf = KGlobal::config();
-
-
+    KConfig* conf = config();
     conf->setGroup("Parameters");
     interval = conf->readUnsignedNumEntry("Interval", 500);
     autoScale = conf->readBoolEntry("AutoScale", true);
@@ -214,42 +214,39 @@ KTimeMon::KTimeMon()
     swapColour = conf->readColorEntry("SwapColour", &swapColour);
     bgColour = conf->readColorEntry("BgColour", &bgColour);
 
-    vertical = conf->readBoolEntry("Vertical", vertical);
+    vertical = conf->readBoolEntry("Vertical", true);
     tooltip = conf->readBoolEntry("Tooltip", true);
 
-    setBackgroundMode(NoBackground); // to avoid flicker
-
     sample = new KSample(this, autoScale, pageScale, swapScale, ctxScale);
 
     timer = new QTimer(this);
     connect(timer, SIGNAL(timeout()), this, SLOT(timeout()));
     timer->start(interval);
 
-    QString aboutmsg;
-    aboutmsg.sprintf(i18n("ktimemon for kdeutils\n"
+    QString aboutmsg = i18n("ktimemon for kdeutils\n"
                           "maintained by Dirk A. Mueller <dmuell@gmx.net>\n"
                           "written by M. Maierhofer (m.maierhofer@tees.ac.uk)\n"
-                          "Based on timemon by H. Maierhofer"));
+                          "Based on timemon by H. Maierhofer");
 
     hmenu = new KHelpMenu(this, aboutmsg);
     menu = new QPopupMenu(this);
 
     menu->insertItem(i18n("Help"), hmenu->menu(), 1);
-    menu->insertItem(i18n("Settings..."), 2);
+    //menu->insertItem(i18n("Settings..."), 2);
     menu->insertItem(i18n("Horizontal bars"), 4);
-    menu->insertSeparator();
-    menu->insertItem(i18n("Quit"), 5);
+    //menu->insertSeparator();
+    //menu->insertItem(i18n("Quit"), 5);
 
     menu->connectItem(2, this, SLOT(configure()));
     menu->connectItem(4, this, SLOT(orientation()));
-    menu->connectItem(5, qApp, SLOT(quit()));
+    //menu->connectItem(5, qApp, SLOT(quit()));
 
     menu->setCheckable(true);
 
-    QSize size(32, 32);
+    QSize size(24, 16);
     resize(conf->readSizeEntry("WidgetSize", &size));
 
-    vertical = !vertical;		// and similar for orientation
+    vertical = !vertical;               // and similar for orientation
     orientation();
 }
 
@@ -302,8 +299,7 @@ void KTimeMon::cont()
 // Dump the current configuration entries to the data base.
 void KTimeMon::writeConfiguration()
 {
-    KConfig* conf = KGlobal::config();
-
+    KConfig* conf = config();
     conf->setGroup("Interface");
     conf->writeEntry("KernelColour", kernelColour);
     conf->writeEntry("UserColour", userColour);
@@ -331,6 +327,7 @@ void KTimeMon::writeConfiguration()
         conf->writeEntry(QString("MouseAction")+n, (unsigned)mouseAction[i]);
         conf->writeEntry(QString("MouseActionCommand")+n, mouseActionCommand[i]);
     }
+    conf->sync();
 }
 
 // Make the KSample object update its internal sample and repaint the
@@ -365,6 +362,10 @@ void KTimeMon::orientation()
 {
     vertical = !vertical;
 
+    KConfig* conf = config();
+    conf->setGroup("Interface");
+    conf->writeEntry("Vertical", vertical);
+
     menu->setItemChecked(4, !vertical);
 
     update();
